/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package dataparsing;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.ArrayList;
import javafx.beans.property.StringProperty;
import javafx.geometry.Insets;
import javafx.scene.control.Label;
import javafx.scene.control.LabelBuilder;
import javafx.scene.control.SeparatorMenuItem;
import javafx.scene.layout.HBox;
import javafx.scene.layout.HBoxBuilder;
import javafx.scene.layout.StackPane;

/**
 *
 * @author Dodo
 */
public class MetaData {
    /**
     * Currency constants
     */
    public static final String [][] currencyValues = {
        {"Australia","Dollar","USDAUD","AUD"},
        {"Brasil","Real","+USDBRL","BRL"},
        {"Canada","Dollar","+USDCAD","CAD"},
        {"China","Yuan","+USDCNY","CNY"},
        {"Denmark","Krone","+USDDKK","DKK"},
        {"Hungary","Forint","+USDHUF","HUF"},
        {"India","Rupee","+USDINR","INR"},
        {"Israel","New Shekel","+USDILS","ILS"},
        {"Japan","Yen","+USDJPY","JPY"},
        {"Mexico","Peso","+USDMXN","MXN"},
        {"Qatar","Riyal","+USDQAR","QAR"},
        {"Russia","Ruble","+USDRUB","RUB"},
        {"Singapore","Dollar","+USDSGD","SGD"},
        {"Sweden","Krona","+USDSEK","SEK"},
        {"Switzerland","Franc","+USDCHF","CHF"},
        {"Turkey","Lyra","+USDTRY","TRY"},
        {"United Kingdom","Pound","+USDGBP","GBP"},
        {"USA","Dollar","+EURUSD","USD"},
    };
    
    public static final String [] stockMarketsAmerica = {
        "^MERV","^BVSP","^GSPTSE","MXX","^GSPC"
    };   
    public static final String [] stockMarketsAsiaPacific = {
        "^AORD","^SSEC","^HSI","^JKSE","^BSESN","^KLSE","^N225","^NZ50","^STI","^KS11","^TWII"
    };
    public static final String [] stockMarketsEuropa = {
        "^ATX","^BFX","^FCHI","^GDAXI","^AEX.AS","^OSEAX","^OMXSPI","^SSMI","^FTSE","FPXAA.PR","GD.AT","MICEXINDEXCF.ME"
    };
    
    /**
     * Creates the API URL 
     */
    public static String generateCurrencyDownloadLink() {
        StringBuilder url = new StringBuilder();
        url.append("http://quote.yahoo.com/d/quotes.csv?s=");
        for(int i = 0; i < currencyValues.length; ++i) {
            url.append(currencyValues[i][2]);
            url.append("=X");
        }
        url.append("&f=sl1&e=.csv");
        return url.toString();
    }
    
    /**
     * Generates an API URL which will download all stock data for a given continent
     * @param market The continent
     * @return The Yahoo Stock API URL
     */
    public static String generateContinentStockMarketName(String market) {
        StringBuilder url = new StringBuilder("");
        
        if(market.equals("America")) {
            for(String s : stockMarketsAmerica) {
                url.append(s);
                url.append(",");
            }
        } else if(market.equals("Asia/Pacific")) {
            for(String s : stockMarketsAsiaPacific) {
                url.append(s);
                url.append(",");
            }
        } else if(market.equals("Europa")) {
            for(String s : stockMarketsEuropa) {
                url.append(s);
                url.append(",");
            }
        }
        
        return url.substring(0, url.length()-2);
    }
    
    /**
     * Returns the API URL
     */
    public static String getStockDownloadLink(String stock) {
        return "http://quote.yahoo.com/d/quotes.csv?s=" + stock + "&f=nsl1p&e=.csv";
    }
    
    /**
     * Creates an HTTP Connection and downloads the .csv file from the API
     * @param urlAddress The API URL
     * @return Array containing the lines of the .csv file
     */
    public static ArrayList<String> loadHttpFile(String urlAddress) {
        HttpURLConnection hc = null;
        InputStream is = null;
        ArrayList<String> values = new ArrayList<String>();
        try {
            URL url = new URL(urlAddress);
            hc = (HttpURLConnection)url.openConnection();
            is = hc.getInputStream();
            String line = null;
            BufferedReader bfr = new BufferedReader(new InputStreamReader(is));
            int cnt = 0;
            while((line = bfr.readLine()) != null) {
                values.add(line);
                cnt++;
            }
        } catch(Exception e1) {
            e1.printStackTrace();
        }
        finally {
            try {
                if(is != null) {
                    is.close();
                }
                if(hc != null) {
                    hc.disconnect();
                }
            } catch(Exception e2) {
                e2.printStackTrace();
            }
        }
        return values;
    }
}
